import 'package:caching/models/application_config.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:caching/local/shared_prefers_helper.dart';
import 'colors.dart';
import 'hex_color.dart';
import 'sizes.dart';

class Styles {

static ThemeData getTheme(ApplicationConfig? appConfig) {
    return ThemeData(
        primaryColor: HexColor(appConfig?.primaryColor),
        primaryColorLight: HexColor(appConfig?.primarySecondColor),
        primaryColorDark: HexColor(appConfig?.primarySecondColor),
        iconTheme: const IconThemeData(color: Colors.white),
        canvasColor: Colors.white,
        dividerColor: Colors.transparent,
        scaffoldBackgroundColor: Colors.white,
        highlightColor: Colors.transparent,
        focusColor: HexColor(appConfig?.primarySecondColor),
        colorScheme: lightColorScheme(appConfig));
  }

  static ColorScheme lightColorScheme(ApplicationConfig? appConfig) {
    return ColorScheme(
      primary: HexColor(appConfig?.primaryColor),
      secondary: HexColor(appConfig?.btnColor),
      background: Colors.white,
      surface: const Color(0xFFFAFBFB),
      onBackground: Colors.white,
      error: Colors.red,
      onError: Colors.red,
      onPrimary: HexColor(appConfig?.primarySecondColor),
      onSecondary: const Color(0xFF322942),
      onSurface: const Color(0xFF241E30),
      brightness: Brightness.light,
    );
  }


  static const _medium = FontWeight.w500;
  static const _regular = FontWeight.w400;

  static TextStyle customTextSmallStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? _regular,
        fontSize: textSize ?? Sizes.TEXT_SIZE_12,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextSmallBoldStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_12,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextSmallItalictStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(
      fontName ?? prefsHelper.getFontName(),
      fontSize: textSize ?? Sizes.TEXT_SIZE_12,
      color: color,
      fontWeight: fontWeight ?? FontWeight.normal,
      fontStyle: FontStyle.italic,
    );
  }

  static TextStyle customTextDefaultStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? _regular,
        fontSize: textSize ?? Sizes.TEXT_SIZE_14,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextDefaultBoldStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_14,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextDefaultItalictStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(
      fontName ?? prefsHelper.getFontName(),
      fontSize: textSize ?? Sizes.TEXT_SIZE_14,
      color: color,
      fontWeight: fontWeight ?? FontWeight.normal,
      fontStyle: FontStyle.italic,
    );
  }

  static TextStyle? customTextMediumStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? _medium,
        fontSize: textSize ?? Sizes.TEXT_SIZE_16,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextMediumItalicStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.normal,
        fontSize: textSize ?? Sizes.TEXT_SIZE_16,
        fontStyle: FontStyle.italic);
  }

  static TextStyle customTextMediumBoldStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_16,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextLargeStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.w500,
        fontSize: textSize ?? Sizes.TEXT_SIZE_18,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextLargeItalicStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.normal,
        fontSize: textSize ?? Sizes.TEXT_SIZE_18,
        fontStyle: FontStyle.italic);
  }

  static TextStyle customTextLargeBoldStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_18,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextHeaderDefaultStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_20,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextHeaderMediumStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_22,
        fontStyle: FontStyle.normal);
  }

  static TextStyle customTextHeaderLargeStyle(
      {Color? color = ThemeColors.textColor,
      String? fontName,
      double? textSize,
      FontWeight? fontWeight}) {
    return GoogleFonts.getFont(fontName ?? prefsHelper.getFontName(),
        color: color,
        fontWeight: fontWeight ?? FontWeight.bold,
        fontSize: textSize ?? Sizes.TEXT_SIZE_26,
        fontStyle: FontStyle.normal);
  }
}
